@@ -1,11 +1,12 @@
 from sys import version_info
 
-if version_info.major == 2:
+if version_info[0] == 2:
     from sys import maxint
 else:
     from sys import maxsize as maxint
 
 from itertools import chain
+from .iters import map, range
 
 class Stream(object):
 
@@ -23,12 +24,13 @@ class Stream(object):
             # check if elements are available for next position
             # return next element or raise StopIteration
             self._position += 1
-            if self._stream._fill_to(self._position):
+            if (len(self._stream._collection) > self._position or 
+                self._stream._fill_to(self._position)):
                 return self._stream._collection[self._position]
 
             raise StopIteration()
 
-        if version_info.major == 2:
+        if version_info[0] == 2:
             next = __next__
 
     def __init__(self):
@@ -41,6 +43,10 @@ class Stream(object):
         self._origin = chain(self._origin, iterator)
         return self
 
+    def cursor(self):
+        """Return position of next evaluated element"""
+        return self._last + 1
+
     def _fill_to(self, index):
         if self._last >= index:
             return True
@@ -57,7 +63,7 @@ class Stream(object):
         return True
 
     def __iter__(self):
-        return Stream._StreamIterator(self)
+        return self._StreamIterator(self)
 
     def __getitem__(self, index):
         if isinstance(index, int):
@@ -65,9 +71,9 @@ class Stream(object):
             if index < 0: raise TypeError("Invalid argument type")
             self._fill_to(index)
         elif isinstance(index, slice):
-            # todo: reimplement to work lazy
             low, high, step = index.indices(maxint)
-            self._fill_to(max(low, high))
+            if step == 0: raise ValueError("Step must not be 0")
+            return self.__class__() << map(self.__getitem__, range(low, high, step or 1))
         else:
             raise TypeError("Invalid argument type")
 
