@@ -33,6 +33,9 @@ class OperatorTestCase(unittest.TestCase):
         # flipping of flipped function should use optimization
         self.assertTrue(operator.sub is op.flip(op.flip(operator.sub)))
 
+    def test_flip_with_shortcut(self):
+        self.assertEqual(10, op.flip(_ - _)(2, 12))
+
     def test_zipwith(self):
         zipper = op.zipwith(operator.add)
         self.assertEqual([10,11,12], list(zipper([0,1,2], itertools.repeat(10))))
@@ -43,6 +46,21 @@ class OperatorTestCase(unittest.TestCase):
         zipper = F() << list << op.zipwith(_ + _)
         self.assertEqual([10,11,12], zipper([0,1,2], itertools.repeat(10)))
 
+    def test_foldl(self):
+        self.assertEqual(10, op.foldl(operator.add)([0,1,2,3,4]))
+        self.assertEqual(20, op.foldl(operator.add, 10)([0,1,2,3,4]))
+        self.assertEqual(20, op.foldl(operator.add, 10)(iters.range(5)))
+        self.assertEqual(10, op.foldl(_ + _)(range(5)))
+
+    def test_foldr(self):
+        summer = op.foldr(operator.add)
+        self.assertEqual(10, op.foldr(operator.add)([0,1,2,3,4]))
+        self.assertEqual(20, op.foldr(operator.add, 10)([0,1,2,3,4]))
+        self.assertEqual(20, op.foldr(operator.add, 10)(iters.range(5)))
+        # specific case for right-side folding
+        self.assertEqual(100, 
+                         op.foldr(op.call, 0)([lambda s: s**2, lambda k: k+10]))
+
 class UnderscoreTestCase(unittest.TestCase):
 
     def test_identity_default(self):
